@@ -105,7 +105,6 @@ DiseasystoreBase <- R6::R6Class(
     #' @param slice_ts `r rd_slice_ts()`
     #' @return
     #'   A tbl_dbi with the requested feature for the study period.
-    #' @importFrom utils packageVersion
     get_feature = function(feature,
                            start_date = self %.% start_date,
                            end_date   = self %.% end_date,
@@ -132,18 +131,7 @@ DiseasystoreBase <- R6::R6Class(
       feature_loader <- purrr::pluck(ds_map, feature)
 
       # Determine where these features are stored
-      target_table_id <- SCDB::id(paste(self %.% target_schema, feature_loader, sep = "."), self %.% target_conn)
-
-      if (packageVersion("SCDB") <= "0.3") {
-        target_table <- paste(
-          c(purrr::pluck(target_table_id, "name", "schema"),
-            purrr::pluck(target_table_id, "name", "table")
-          ),
-          collapse = "."
-        )
-      } else {
-        target_table <- target_table_id # From SCDB 0.4 we can use the Id everywhere
-      }
+      target_table <- SCDB::id(paste(self %.% target_schema, feature_loader, sep = "."), self %.% target_conn)
 
 
       # Create log table
@@ -159,30 +147,13 @@ DiseasystoreBase <- R6::R6Class(
       # If there are any missing ranges, put a lock on the data base
       if (nrow(ds_missing_ranges) > 0) {
 
-        if (packageVersion("SCDB") <= "0.3") {
-          # Add a LOCK to the diseasystore
-          add_table_lock(self %.% target_conn, target_table, self %.% target_schema)
-
-          # Check if we have ownership of the update of the target_table
-          # If not, keep retrying and wait for up to 30 minutes before giving up
-          wait_time <- 0 # seconds
-          while (!isTRUE(is_lock_owner(self %.% target_conn, target_table, self %.% target_schema))) {
-            Sys.sleep(diseasyoption("lock_wait_increment"))
-            add_table_lock(self %.% target_conn, target_table, self %.% target_schema)
-            wait_time <- wait_time + diseasyoption("lock_wait_increment")
-            if (wait_time > diseasyoption("lock_wait_max")) {
-              stop(glue::glue("Lock not released within {diseasyoption('lock_wait_max')/60} minutes. Giving up."))
-            }
-          }
-        } else {
-          # Add a LOCK to the diseasystore
-          wait_time <- 0 # seconds
-          while (!isTRUE(SCDB::lock_table(self %.% target_conn, target_table, self %.% target_schema))) {
-            Sys.sleep(diseasyoption("lock_wait_increment"))
-            wait_time <- wait_time + diseasyoption("lock_wait_increment")
-            if (wait_time > diseasyoption("lock_wait_max")) {
-              stop(glue::glue("Lock not released within {diseasyoption('lock_wait_max')/60} minutes. Giving up."))
-            }
+        # Add a LOCK to the diseasystore
+        wait_time <- 0 # seconds
+        while (!isTRUE(SCDB::lock_table(self %.% target_conn, target_table, self %.% target_schema))) {
+          Sys.sleep(diseasyoption("lock_wait_increment"))
+          wait_time <- wait_time + diseasyoption("lock_wait_increment")
+          if (wait_time > diseasyoption("lock_wait_max")) {
+            stop(glue::glue("Lock not released within {diseasyoption('lock_wait_max')/60} minutes. Giving up."))
           }
         }
 
@@ -217,7 +188,7 @@ DiseasystoreBase <- R6::R6Class(
 
           # Add the existing computed data for given slice_ts
           if (SCDB::table_exists(self %.% target_conn, target_table)) {
-            ds_existing <- dplyr::tbl(self %.% target_conn, target_table_id, check_from = FALSE)
+            ds_existing <- dplyr::tbl(self %.% target_conn, target_table)
 
             if (SCDB::is.historical(ds_existing)) {
               ds_existing <- ds_existing |>
@@ -237,28 +208,21 @@ DiseasystoreBase <- R6::R6Class(
             self %.% target_conn
           )
 
-          if (packageVersion("SCDB") <= "0.3") {
-            logger <- SCDB::Logger$new(
-              output_to_console = FALSE,
-              log_table_id = log_table_id,
-              log_conn = self %.% target_conn
-            )
-          } else {
-            logger <- SCDB::Logger$new(
-              db_table = target_table,
-              timestamp = slice_ts,
-              output_to_console = FALSE,
-              log_table_id = log_table_id,
-              log_conn = self %.% target_conn
-            )
-          }
+          logger <- SCDB::Logger$new(
+            db_table = target_table,
+            timestamp = slice_ts,
+            output_to_console = FALSE,
+            log_table_id = log_table_id,
+            log_conn = self %.% target_conn
+          )
+
 
 
           # Commit to DB
           SCDB::update_snapshot(
             .data = ds_updated_feature,
             conn = self %.% target_conn,
-            db_table = target_table_id,
+            db_table = target_table,
             timestamp = slice_ts,
             message = glue::glue("ds-range: {start_date} - {end_date}"),
             logger = logger,
@@ -267,11 +231,7 @@ DiseasystoreBase <- R6::R6Class(
         })
 
         # Release the lock on the table
-        if (packageVersion("SCDB") <= "0.3") {
-          remove_table_lock(self %.% target_conn, target_table, self %.% target_schema)
-        } else {
-          SCDB::unlock_table(self %.% target_conn, target_table, self %.% target_schema)
-        }
+        SCDB::unlock_table(self %.% target_conn, target_table, self %.% target_schema)
 
         # Inform how long has elapsed for updating data
         if (private$verbose && nrow(ds_missing_ranges) > 0) {
@@ -282,7 +242,7 @@ DiseasystoreBase <- R6::R6Class(
 
       # Finally, return the data to the user
       out <- do.call(what = purrr::pluck(private, feature_loader) %.% get,
-                     args = list(target_table = target_table_id,
+                     args = list(target_table = target_table,
                                  slice_ts = slice_ts, target_conn = self %.% target_conn))
 
       # We need to slice to the period of interest.
@@ -633,19 +593,11 @@ DiseasystoreBase <- R6::R6Class(
     #' @importFrom zoo as.Date
     determine_new_ranges = function(target_table, start_date, end_date, slice_ts) {
 
-      if (packageVersion("SCDB") <= "0.3" && inherits(target_table, "Id")) {
-        target_table <- paste(
-          c(purrr::pluck(target_table, "schema"),
-            purrr::pluck(target_table, "table")
-          ),
-          collapse = "."
-        )
-      }
-
       # Get a list of the logs for the target_table on the slice_ts
-      logs <- dplyr::tbl(self %.% target_conn,
-                         SCDB::id(paste(self %.% target_schema, "logs", sep = "."), self %.% target_conn),
-                         check_from = FALSE) |>
+      logs <- dplyr::tbl(
+        self %.% target_conn,
+        SCDB::id(paste(self %.% target_schema, "logs", sep = "."), self %.% target_conn)
+      ) |>
         dplyr::collect() |>
         tidyr::unite("target_table", "schema", "table", sep = ".", na.rm = TRUE) |>
         dplyr::filter(.data$target_table == !!as.character(target_table), .data$date == !!slice_ts)
